shewhart computes, and, optionally, plots,
Shewhart-type Phase I control charts for detecting
changes in location and scale of univariate subgrouped data.
shewhart.normal.limits pre-computes
the corresponding control limits when the in-control distribution is normal.
shewhart(x, subset, stat = c("XbarS", "Xbar", "S", "Rank", "lRank", "sRank"),
aggregation = c("median", "mean"), plot = TRUE, FAP = 0.05,
seed = 11642257, L = if (stat %in% c("XbarS", "Xbar", "S")) 1000 else 100000,
limits = NA)shewhart.normal.limits(n, m, stat = c("XbarS", "Xbar", "S", "Rank", "lRank", "sRank"),
aggregation = c("median", "mean"), FAP = 0.05,
seed = 11642257, L = 100000)
shewhart returns an invisible list with elements
Xbar subgroup means; this element is present only if
stat is XbarS or Xbar.
S subgroup standard deviation; this element is present only if
stat is XbarS or S.
lRank rank-based control statistics for detecting
changes in location; this element is present only if
stat is Rank or lRank.
sRank rank-based control-statistics for detecting
changes in scale; this element is present only if
stat is Rank or sRank.
limits control limits.
center, scale estimates
\(\hat{\mu}\) and \(\hat{\sigma}\) of the in-control
mean and standard deviation; these elements are present only if
stat is XbarS, Xbar and S.
stat, L, aggregation, FAP,
seed input arguments.
shewhart.normal.limits returns a numeric vector
containing the limits.
a nxm data numeric matrix (n observations gathered at m time points).
integer: size of each subgroup (number of observations gathered at each time point).
integer: number of subgroups (time points).
an optional vector specifying a subset of subgroups/time points to be used
character: the control statistic[s] to use; see Details.
character:
it specify how to aggregate the subgroup means and standard deviations.
Used only when stat is XbarS, Xbar or S.
logical; if TRUE, control statistic[s] is[are] displayed.
numeric (between 0 and 1): desired false alarm probability.
positive integer; if not NA, the RNG's state is resetted
using seed. The current .Random.seed will be
preserved.
Unused by shewhart when limits is not NA.
positive integer: number of Monte Carlo replications used to
compute the control limits. Unused by shewhart when limits is not NA.
numeric: a precomputed vector of control limits.
The vector should contain \((A,B_1,B_2)\)
when stat=XbarS, \((A)\) when stat=Xbar,
\((B_1,B_2)\) when stat=S,
\((C,D)\) when stat=Rank, \((C)\) when
stat=lRank and \((D)\) when stat=sRank.
See Details for the definition of the critical values
\(A\), \(B_1\), \(B_2\), \(C\) and \(D\).
tools:::Rd_package_author("dfphase1").
The implemented control charts are:
XbarS: combination of the Xbar
and S control charts described in the following.
Xbar: chart based on plotting the subgroup means with control limits
$$\hat{\mu}\pm A\frac{\hat{\sigma}}{\sqrt{n}}$$
where \(\hat{\mu}\) (\(\hat{\sigma}\))
denotes the estimate of the in-control mean (standard deviation)
computed as the mean or median of the subgroup means (standard
deviations).
S: chart based on plotting the (unbiased) subgroup standard deviations
with lower control limit \(B_1\hat{\sigma}\) and
upper control limit \(B_2\hat{\sigma}\).
Rank: combination of the lRank
and sRank control charts described in the following.
lRank: control chart based on the standardized
rank-sum control statistic suggested by
Jones-Farmer et al. (2009) for detecting changes in the location parameter.
Control limits are of the type \(\pm C\).
sRank: control chart based on the standardized
rank-sum control statistic suggested by
Jones-Farmer and Champ (2010) for detecting changes in the scale parameter.
Control limits are of the type \(\pm D\).
L. A. Jones-Farmer, V. Jordan, C. W. Champs (2009) “Distribution-free Phase I control charts for subgroup location”, Journal of Quality Technology, 41, pp. 304--316, tools:::Rd_expr_doi("10.1080/00224065.2009.11917784").
L. A. Jones-Farmer, C. W. Champ (2010) “A distribution-free Phase I control chart for subgroup scale”. Journal of Quality Technology, 42, pp. 373--387, tools:::Rd_expr_doi("10.1080/00224065.2010.11917834")
D. C. Montgomery (2009) Introduction to Statistical Quality Control, 6th edn. Wiley.
P. Qiu (2013) Introduction to Statistical Process Control. Chapman & Hall/CRC Press.
# A simulated example
set.seed(12345)
y <- matrix(rt(100,3),5)
y[,20] <- y[,20]+3
shewhart(y)
# Reproduction of the control charts shown
# by Jones-Farmer et. al. (2009,2010)
data(colonscopy)
u <- shewhart.normal.limits(NROW(colonscopy),NCOL(colonscopy),stat="lRank",FAP=0.1)
u
# control limits based on a limited number of replications
# to avoid a (relatively) long execution time
shewhart(colonscopy,stat="lRank",limits=u,L=10000)
shewhart(colonscopy,stat="sRank",FAP=0.1,L=10000)
Run the code above in your browser using DataLab